==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/TableTennisPaddleBall.md <==
# TableTennisPaddleBall


```text
fontawesome-6/Solid/TableTennisPaddleBall
```

```text
include('fontawesome-6/Solid/TableTennisPaddleBall')
```



| Illustration | TableTennisPaddleBall |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/TableTennisPaddleBall.png) | ![illustration for TableTennisPaddleBall](../../fontawesome-6/Solid/TableTennisPaddleBall.Local.png) |




## TableTennisPaddleBall

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TableTennisPaddleBall
include('fontawesome-6/Solid/TableTennisPaddleBall')

' renders the element
TableTennisPaddleBall('TableTennisPaddleBall', 'Table Tennis Paddle Ball', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TableTennisPaddleBall
include('fontawesome-6/Solid/TableTennisPaddleBall')

' renders the element
TableTennisPaddleBall('TableTennisPaddleBall', 'Table Tennis Paddle Ball', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/TableTennisPaddleBall.md <==
# TableTennisPaddleBall


```text
fontawesome-6/Solid/TableTennisPaddleBall
```

```text
include('fontawesome-6/Solid/TableTennisPaddleBall')
```



| Illustration | TableTennisPaddleBall |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/TableTennisPaddleBall.png) | ![illustration for TableTennisPaddleBall](../../fontawesome-6/Solid/TableTennisPaddleBall.Local.png) |




## TableTennisPaddleBall

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TableTennisPaddleBall
include('fontawesome-6/Solid/TableTennisPaddleBall')

' renders the element
TableTennisPaddleBall('TableTennisPaddleBall', 'Table Tennis Paddle Ball', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TableTennisPaddleBall
include('fontawesome-6/Solid/TableTennisPaddleBall')

' renders the element
TableTennisPaddleBall('TableTennisPaddleBall', 'Table Tennis Paddle Ball', 'an optional tech label', 'an optional description')
@enduml
```
